// 在main.js上通过import引入Vue库和自己写的Vue组件库
import Vue from "vue";
import "vant/lib/index.css";
import { Tab, Tabs } from "vant";
import { DatetimePicker } from "vant";
import { Popup } from "vant";
import { Image as VanImage } from "vant";
import { ActionSheet } from "vant";

Vue.use(Tab);
Vue.use(Tabs);
Vue.use(DatetimePicker);
Vue.use(Popup);
Vue.use(VanImage);
Vue.use(ActionSheet);

import DataStatistics from "./components/dataStatistics.vue";
import eventBus from "../../../../../../util/eventBus";
(function (KDApi) {
  function MyComponent(model) {
    this._setModel(model);
  }

  MyComponent.prototype = {
    _setModel: function (model) {
      this.model = model;
    },
    init: function (props) {
      console.log("===init===", this.model, props);
      setHtml(this.model, props);
    },
    update: function (props) {
      console.log("===update===", this.model, props);
      eventBus.pub(this.model, "update", props);
    },
    destoryed: function () {
      console.log("===destoryed===", this.model);
      eventBus.unsub(this.updateSub);
      eventBus.unsub(this.toDetailDataSub);
    },
  };

  const setHtml = (model, props) => {
    const { invoke } = model;

    KDApi.loadFile("./css/index.css", model, () => {
      new Vue({
        el: model.dom,
        template: `<DataStatistics v-on:tabChange="tabChange" v-on:toDetail="toDetail"/>`,
        components: {
          DataStatistics,
        },
        data: function () {
          return {};
        },
        mounted() {
          let self = this;
          this.updateSub = eventBus.sub(model, "update", (data) => {
            self.initData(data);
          });

          self.initData(props);
        },
        methods: {
          //后端传递的数据
          initData(props) {
            if (props && props.data) {
              this.handleData(props.data);
            } else {
            }
          },
          handleData(data) {
            console.log("==data==", data);
            let tempData = {};
            //type 1是客户数据  2是队伍数据  3是行为数据
            switch (data.type) {
              case 1:
                // tempData = {
                //   agencyChartData: [
                //     { value: data.companyTotalNum, name: "区域机构总数" },
                //     { value: data.visitCompanyNum, name: "拜访机构数" },
                //   ], //机构图表数据
                //   agencyTotal: data.companyTotalNum, //区域机构总数
                //   agencyVisitCount: data.visitCompanyNum, //拜访机构数
                //   customerChartData: [
                //     { value: data.customerTotalNum, name: "绑定客户数" },
                //     { value: data.visitCustomer, name: "拜访客户数" },
                //   ], //客户图表数据
                //   customerBindCount: data.customerTotalNum, //绑定客户数
                //   customerVisitCount: data.visitCustomer, //拜访客户数
                //   bindPercent: data.bindCustomerRate, //绑定覆盖率
                //   visitPercent: data.visitCustomerRate, //拜访客户覆盖率
                //   type: 1,
                // };
                tempData = {
                  agencyChartData: [
                    { value: 30, name: "区域机构总数" },
                    { value: 70, name: "拜访机构数" },
                  ], //机构图表数据
                  agencyTotal: 100, //区域机构总数
                  agencyVisitCount: 70, //拜访机构数
                  customerChartData: [
                    { value: 20, name: "绑定客户数" },
                    { value: 80, name: "拜访客户数" },
                  ], //客户图表数据
                  customerBindCount: 200, //绑定客户数
                  customerVisitCount: 120, //拜访客户数
                  bindPercent: 65, //绑定覆盖率
                  visitPercent: 80, //拜访客户覆盖率
                  type: 1,
                };
                break;
              case 2:
                // tempData = {
                //   teamChartData: [
                //     { value: data.adminNum, name: "管理人数" },
                //     { value: data.visitedNum, name: "参加拜访人数" },
                //   ], //队伍图表数据
                //   allNum: data.allNum, //队伍人数
                //   adminNum: data.adminNum, //管理人数
                //   visitedNum: data.visitedNum, //参加拜访人数
                //   type: 2,
                // };
                tempData = {
                  teamChartData: [
                    { value: 70, name: "管理人数" },
                    { value: 30, name: "参加拜访人数" },
                  ], //队伍图表数据
                  allNum: 100, //队伍人数
                  adminNum: 3, //管理人数
                  visitedNum: 30, //参加拜访人数
                  type: 2,
                };
                break;
              case 3:
                // tempData = {
                //   visitChartData: [
                //     { value: data.visitTotalNum, name: "拜访总次数" },
                //     { value: data.visitedNum, name: "有效拜访总次数" },
                //   ], //拜访图表数据
                //   visitTotalNum: data.visitTotalNum, //拜访总次数
                //   visitedNum: data.visitedNum, //有效拜访总次数
                //   type: 3,
                // };
                tempData = {
                  visitChartData: [
                    { value: 70, name: "拜访总次数" },
                    { value: 30, name: "有效拜访总次数" },
                  ], //拜访图表数据
                  visitTotalNum: 100, //拜访总次数
                  visitedNum: 30, //有效拜访总次数
                  type: 3,
                };
                break;
            }

            if (data.isFirstLoad && data.isFirstLoad == 1) {
              tempData.isFirstLoad = data.isFirstLoad;
              tempData.role = data.role;
              tempData.provinceId = data.provinceId;
              tempData.departmentId = data.departmentId;
              tempData.provinceCompany = data.provinceCompany;
              tempData.department = data.department;
            }

            eventBus.pubCustom(
              "dataStatistics_indexData",
              "indexData",
              tempData
            );
          },
          //切换tab
          tabChange(type) {
            this.invoke("tabChange", { div: type });
          },
          //跳转详情页
          toDetail(data) {
            this.invoke("toDetail", data);
          },
          //发送数据给后端
          invoke: function (eventName, args) {
            invoke(eventName, args);
          },
        },
      });
    });
  };

  // 注册自定义组件
  KDApi.register("dataStatisticsKy", MyComponent);
})(window.KDApi);
